==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomDeploymentStrategyParamsBuilder extends io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluentImpl<io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.CustomDeploymentStrategyParams,io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsBuilder>{
  public CustomDeploymentStrategyParamsBuilder() {
    this(false);
  }
  public CustomDeploymentStrategyParamsBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomDeploymentStrategyParams(), validationEnabled);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomDeploymentStrategyParams(), validationEnabled);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance) {
    this(fluent, instance, false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommand(instance.getCommand()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withImage(instance.getImage()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance) {
    this(instance,false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommand(instance.getCommand()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withImage(instance.getImage()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.CustomDeploymentStrategyParams build() {
    CustomDeploymentStrategyParams buildable = new CustomDeploymentStrategyParams(fluent.getCommand(),fluent.getEnvironment(),fluent.getImage());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomDeploymentStrategyParamsBuilder that = (CustomDeploymentStrategyParamsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomDeploymentStrategyParamsBuilder extends io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluentImpl<io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.CustomDeploymentStrategyParams,io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsBuilder>{
  public CustomDeploymentStrategyParamsBuilder() {
    this(false);
  }
  public CustomDeploymentStrategyParamsBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomDeploymentStrategyParams(), validationEnabled);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomDeploymentStrategyParams(), validationEnabled);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance) {
    this(fluent, instance, false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent,io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCommand(instance.getCommand()); 
    fluent.withEnvironment(instance.getEnvironment()); 
    fluent.withImage(instance.getImage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance) {
    this(instance,false);
  }
  public CustomDeploymentStrategyParamsBuilder(io.fabric8.openshift.api.model.CustomDeploymentStrategyParams instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCommand(instance.getCommand()); 
    this.withEnvironment(instance.getEnvironment()); 
    this.withImage(instance.getImage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.CustomDeploymentStrategyParamsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.CustomDeploymentStrategyParams build() {
    CustomDeploymentStrategyParams buildable = new CustomDeploymentStrategyParams(fluent.getCommand(),fluent.getEnvironment(),fluent.getImage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomDeploymentStrategyParamsBuilder that = (CustomDeploymentStrategyParamsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
